


from kraken_html.html_table import Html_table
from kraken_html.html_record import Html_record
from kraken_html.html_card import Html_card

from kraken_html.html_section import Html_section
from kraken_html.html_bootstrap import Html_bootstrap
from kraken_html.html_navbar import Html_navbar


#from models.html_form import Html_form


class Kraken_html:

    def __init__(self, title = None):


        self.nav = []
        self.title = title



    def table(self, value):


        html_table = Html_table()
        keys = self._get_keys(value)

        return html_table.table(keys, value)


    def record(self, value):


        html_record = Html_record()

        keys = self._get_keys(value)


        return html_record.record(keys, value)


    def record_detail(self, value):


        html_record = Html_record()

        keys = self._get_keys(value)


        return html_record.record_detail(keys, value)




    def form(self, value):

        if value:
            self.value = value

        return 


    def cards(self, value):



        html_card = Html_card()

        return html_card.cards(value)



    def section(self, title, content):




        html_section = Html_section()

        return html_section.section(title, content)




    def bootstrap(self, nav, title, content):

        html_bootstrap = Html_bootstrap()

        return html_bootstrap.bootstrap(nav, title, content)




    def navbar(self, title, value):

        html_navbar = Html_navbar()

        return html_navbar.navbar(title, value)



    def page(self, content = ''):

        
        
        html_nav = self.navbar(self.title, self.nav)


        content = self.bootstrap(html_nav, self.title, content)

        return content



    def _get_keys(self, value):

        if not isinstance(value, list):
            value = [value]

        keys = []

        for i in value:
            for key in i:
                if key not in keys:
                    keys.append(key)

        return sorted(keys)





class Html_card:

    def __init__(self):

        a = 1

    def card(self, title, text, contenturl, url):



        card = '''
            <div class="card">
                <img class="card-img-top" src="{card_url}" alt="Card image cap">
                <div class="card-body">
                <h6 class="card-title">{card_title}</h6>
                <p class="card-text">{card_text}</p>
                </div>
                <div class="card-footer">
                <small class="text-muted">Last updated 3 mins ago</small>
                </div>
            </div>
                '''
        d = { 'card_title': title, 'card_text': text, 'card_url': contenturl, 'card_record_link': url }
        content = card.format(**d)

        return content

    def card_backup(self, title, contenturl, url):



        card = '''
            <a href="{card_record_link}">
            <div class="card">
                <img src="{card_url}" class="card-img-top" alt="{card_title}">
                <div class="card-body">
                
                </div></div>
                </a>
                '''
        d = { 'card_title': title, 'card_url': contenturl, 'card_record_link': url }
        content = card.format(**d)

        return content


    def cards(self, values):

        content = ''
        content += '<div class="card-columns">'

        for i in values:

            title = self._get_title(i)
            contenturl = self._get_contenturl(i)
            url = self._get_record_url(i)

            content += self.card(title, '', contenturl, url)

        content += '</div>'

        return content




    def _get_contenturl(self, value):

        contenturl = None

        fields = ['schema:contenturl', 'schema:thumbnailurl']

        for i in fields:
            contenturl = value.get(i, None)
            if contenturl:
                return contenturl

        return ''

    def _get_title(self, value):

        new_value = None

        fields = ['schema:name', '@id']

        for i in fields:
            new_value = value.get(i, None)
            if new_value:
                return new_value

        return ''

    def _get_record_url(self, value):

        new_value = '/' + value.get('@type', None) + '/' + value.get('@id', None)

        return new_value



from kraken_html.html_field import Html_field

from dateutil.parser import parse

class Html_record:

    def __init__(self):

        a=1

    def record(self, keys, value):

        # Define link data. 
        record_type = value.get('@type', None)
        record_id = value.get('@id', None)



        content = ''

        content += '<div class="container-fluid">'

        content += '<dl class="row">'

        for i in keys:

            cell_value = value.get(i, None)

            # Convert value into datatype (url, etc)
            cell_value = value.get(i, None)
            html_field = Html_field()
            i_value = html_field.get(record_type, record_id, i, cell_value)
            

            content += self._record_line(i, i_value)

        content += '</dl>'

        content += '</div>'

        return content

    def _record_line(self, key, value):

        content = ''
        content +=  '<dt class="col-sm-3">'
        content +=  str(key) 
        content += ':</dt>'
        content += '<dd class="col-sm-9">'
        content += value 
        content += '</dd>'

        return content


    def record_detail(self, keys, value):

        # Define link data. 
        record_type = value.get('@type', None)
        record_id = value.get('@id', None)



        content = ''

        content += '<div class="container-fluid">'

        content += '<dl class="row">'

        for i in keys:

            cell_value = value.get(i, None)

            # If not dict, then single line
            if not isinstance(cell_value, dict):
                # Convert value into datatype (url, etc)
                cell_value = value.get(i, None)
                html_field = Html_field()
                i_value = html_field.get(record_type, record_id, i, cell_value)
                
                content += self._record_line(i, i_value)

            else:

                # COnvert value into datatype (url, etc)
                cell_dict = value.get(i, None)
                cell_value = cell_dict.get('value', '')
                
                html_field = Html_field()

                cell_dict['value'] = html_field.get(record_type, record_id, i, cell_value)
                
                content += self._record_line_detail(i, cell_dict)

        content += '</dl>'

        content += '</div>'

        return content
    
    
    
    def _record_line_detail(self, key, value):

        # Shows full data info (credibility, etc)




        # Define list of keys, value first then alpha
        keys = ['value']
        all_keys = sorted(value.keys())
        for i in all_keys:
            if i not in keys:
                keys.append(i)


        # Start generating html

        content = ''
        content +=  '<dt class="col-sm-3">'
        content +=  str(key) 
        content += ':</dt>'


        content += '<dd class="col-sm-9">'
        
        
        content += '<dl class="row">'


        # Define list of keys, value first then alpha
        keys = ['value']
        all_keys = sorted(value.keys())
        for i in all_keys:
            if i not in keys:
                keys.append(i)

        # Generate subtable
        for i in keys:
            i_value = value.get(i, '')
            content += '<dt class="col-sm-4">{i}</dt>'.format(i=i)
            content += '<dd class="col-sm-8">{i_value}</dd>'.format(i_value = i_value)
        
        
        content += '</dl>'
        
        
        
        #content += value 
        content += '</dd>'

        return content